==> huaweicloudsdkrocketmq-3.1.52-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/list_brokers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBrokersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'brokers': 'list[ListBrokersRespBrokers]'
    }

    attribute_map = {
        'brokers': 'brokers'
    }

    def __init__(self, brokers=None):
        """ListBrokersResponse

        The model defined in huaweicloud sdk

        :param brokers: 代理列表。
        :type brokers: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        
        super(ListBrokersResponse, self).__init__()

        self._brokers = None
        self.discriminator = None

        if brokers is not None:
            self.brokers = brokers

    @property
    def brokers(self):
        """Gets the brokers of this ListBrokersResponse.

        代理列表。

        :return: The brokers of this ListBrokersResponse.
        :rtype: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        return self._brokers

    @brokers.setter
    def brokers(self, brokers):
        """Sets the brokers of this ListBrokersResponse.

        代理列表。

        :param brokers: The brokers of this ListBrokersResponse.
        :type brokers: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        self._brokers = brokers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBrokersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrocketmq-3.1.145-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/list_brokers_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBrokersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'brokers': 'list[ListBrokersRespBrokers]'
    }

    attribute_map = {
        'brokers': 'brokers'
    }

    def __init__(self, brokers=None):
        r"""ListBrokersResponse

        The model defined in huaweicloud sdk

        :param brokers: 代理列表。
        :type brokers: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        
        super(ListBrokersResponse, self).__init__()

        self._brokers = None
        self.discriminator = None

        if brokers is not None:
            self.brokers = brokers

    @property
    def brokers(self):
        r"""Gets the brokers of this ListBrokersResponse.

        代理列表。

        :return: The brokers of this ListBrokersResponse.
        :rtype: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        return self._brokers

    @brokers.setter
    def brokers(self, brokers):
        r"""Sets the brokers of this ListBrokersResponse.

        代理列表。

        :param brokers: The brokers of this ListBrokersResponse.
        :type brokers: list[:class:`huaweicloudsdkrocketmq.v2.ListBrokersRespBrokers`]
        """
        self._brokers = brokers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBrokersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
